@@ -8,10 +8,11 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
-from abc import ABC, abstractmethod
+from abc import ABC
 from typing import Optional
 
 from pip_services3_commons.config import ConfigParams
+from pip_services3_commons.run import INotifiable
 
 
 class IConfigReader(ABC):
@@ -24,7 +25,7 @@ class IConfigReader(ABC):
     The values may come from application command like arguments or environment variables.
     """
 
-    def _read_config(self, correlation_id: Optional[str], parameters: ConfigParams) -> ConfigParams:
+    def read_config_(self, correlation_id: Optional[str], parameters: ConfigParams) -> ConfigParams:
         """
         Reads configuration and parameterize it with given values.
 
@@ -35,3 +36,19 @@ class IConfigReader(ABC):
         :return: ConfigParams configuration.
         """
         raise NotImplementedError('Method from interface definition')
+
+    def add_change_listener(self, listener: INotifiable):
+        """
+        Adds a listener that will be notified when configuration is changed
+
+        :param listener: a listener to be added.
+        """
+        raise NotImplementedError('Method from interface definition')
+
+    def remove_change_listener(self, listener: INotifiable):
+        """
+        Remove a previously added change listener.
+
+        :param listener: a listener to be removed.
+        """
+        raise NotImplementedError('Method from interface definition')
